/* Copyright (C) 2002, 2003, 2004, 2007 Jordi Burguet-Castell
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to:
 *   Free Software Foundation, Inc.
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 */

#ifndef __TENSOR_H__
#define __TENSOR_H__

#include "tensor_complex_double.h"

#include "tensor_long_double.h"
#include "tensor_double.h"
#include "tensor_float.h"

#include "tensor_ulong.h"
#include "tensor_long.h"

#include "tensor_uint.h"
#include "tensor_int.h"

#include "tensor_ushort.h"
#include "tensor_short.h"

#include "tensor_uchar.h"
#include "tensor_char.h"


#endif /* __TENSOR_H__ */
